@@ -4,8 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef BACKUPER_H
-#define BACKUPER_H
+#pragma once
 
 #include "options.h"
 
@@ -45,4 +44,3 @@ private:
     bool m_backupInProgress;
 };
 
-#endif // BACKUPER_H
